================================
:code:`Trakt['users/*/friends']`
================================

.. automodule:: trakt.interfaces.users.friends

  .. autoclass:: UsersFriendsInterface
    :members: get
    :undoc-members:
